# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventBindRequest(Model):
    """ActivityEventBindRequest.

    All required parameters must be populated in order to send to Azure.

    :param bind_type: Required. Possible values include: 'Group', 'Metric',
     'EvidenceMetric', 'Model', 'GroupModel'
    :type bind_type: str or ~smartdiagnostics_sdk.models.enum
    :param bind_id: Required.
    :type bind_id: str
    """

    _validation = {
        'bind_type': {'required': True},
        'bind_id': {'required': True},
    }

    _attribute_map = {
        'bind_type': {'key': 'BindType', 'type': 'str'},
        'bind_id': {'key': 'BindId', 'type': 'str'},
    }

    def __init__(self, *, bind_type, bind_id: str, **kwargs) -> None:
        super(ActivityEventBindRequest, self).__init__(**kwargs)
        self.bind_type = bind_type
        self.bind_id = bind_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventCategoryResponse(Model):
    """ActivityEventCategoryResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: int
    :param code: Required.
    :type code: str
    :param name:
    :type name: str
    :param description:
    :type description: str
    :param activity_line_enabled:
    :type activity_line_enabled: bool
    :param activity_line_flag:
    :type activity_line_flag: str
    :param asset_card_enabled:
    :type asset_card_enabled: bool
    :param owner:
    :type owner: ~smartdiagnostics_sdk.models.ActivityEventCategoryOwnerChild
    :param internal:
    :type internal: bool
    :param subcategories:
    :type subcategories:
     list[~smartdiagnostics_sdk.models.ActivityEventSubcategoryChild]
    :param fields:
    :type fields: list[~smartdiagnostics_sdk.models.ActivityEventFieldChild]
    """

    _validation = {
        'id': {'required': True},
        'code': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'int'},
        'code': {'key': 'Code', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'description': {'key': 'Description', 'type': 'str'},
        'activity_line_enabled': {'key': 'ActivityLineEnabled', 'type': 'bool'},
        'activity_line_flag': {'key': 'ActivityLineFlag', 'type': 'str'},
        'asset_card_enabled': {'key': 'AssetCardEnabled', 'type': 'bool'},
        'owner': {'key': 'Owner', 'type': 'ActivityEventCategoryOwnerChild'},
        'internal': {'key': 'Internal', 'type': 'bool'},
        'subcategories': {'key': 'Subcategories', 'type': '[ActivityEventSubcategoryChild]'},
        'fields': {'key': 'Fields', 'type': '[ActivityEventFieldChild]'},
    }

    def __init__(self, **kwargs):
        super(ActivityEventCategoryResponse, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.code = kwargs.get('code', None)
        self.name = kwargs.get('name', None)
        self.description = kwargs.get('description', None)
        self.activity_line_enabled = kwargs.get('activity_line_enabled', None)
        self.activity_line_flag = kwargs.get('activity_line_flag', None)
        self.asset_card_enabled = kwargs.get('asset_card_enabled', None)
        self.owner = kwargs.get('owner', None)
        self.internal = kwargs.get('internal', None)
        self.subcategories = kwargs.get('subcategories', None)
        self.fields = kwargs.get('fields', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventSubcategoryResponse(Model):
    """ActivityEventSubcategoryResponse.

    :param id:
    :type id: str
    :param code:
    :type code: str
    :param name:
    :type name: str
    :param description:
    :type description: str
    :param location_id:
    :type location_id: str
    """

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'code': {'key': 'Code', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'description': {'key': 'Description', 'type': 'str'},
        'location_id': {'key': 'LocationId', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ActivityEventSubcategoryResponse, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.code = kwargs.get('code', None)
        self.name = kwargs.get('name', None)
        self.description = kwargs.get('description', None)
        self.location_id = kwargs.get('location_id', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ThermalCameraCreateRequest(Model):
    """Request object to create a ThermalCamera and its settings.

    All required parameters must be populated in order to send to Azure.

    :param serial_number: Required. Unique serial number of the camera.
    :type serial_number: long
    :param location_id: Required. The Location/Account ID
    :type location_id: str
    :param settings: Required.
    :type settings:
     ~smartdiagnostics_sdk.models.ThermalCameraSettingsCreateRequest
    """

    _validation = {
        'serial_number': {'required': True},
        'location_id': {'required': True},
        'settings': {'required': True},
    }

    _attribute_map = {
        'serial_number': {'key': 'SerialNumber', 'type': 'long'},
        'location_id': {'key': 'LocationId', 'type': 'str'},
        'settings': {'key': 'Settings', 'type': 'ThermalCameraSettingsCreateRequest'},
    }

    def __init__(self, **kwargs):
        super(ThermalCameraCreateRequest, self).__init__(**kwargs)
        self.serial_number = kwargs.get('serial_number', None)
        self.location_id = kwargs.get('location_id', None)
        self.settings = kwargs.get('settings', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AnalyticsModelUpdateRequest(Model):
    """AnalyticsModelUpdateRequest.

    All required parameters must be populated in order to send to Azure.

    :param is_deprecated: Required.
    :type is_deprecated: bool
    :param triggers:
    :type triggers: list[~smartdiagnostics_sdk.models.TriggerChild]
    """

    _validation = {
        'is_deprecated': {'required': True},
    }

    _attribute_map = {
        'is_deprecated': {'key': 'IsDeprecated', 'type': 'bool'},
        'triggers': {'key': 'Triggers', 'type': '[TriggerChild]'},
    }

    def __init__(self, *, is_deprecated: bool, triggers=None, **kwargs) -> None:
        super(AnalyticsModelUpdateRequest, self).__init__(**kwargs)
        self.is_deprecated = is_deprecated
        self.triggers = triggers



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SmartAlarmsRequest(Model):
    """SmartAlarmsRequest.

    :param end_date: The end date of data to calculate smart alarms for.
    :type end_date: datetime
    :param coefficient: The coefficent to calculate SmartAlarm values. Must be
     between 0-5
    :type coefficient: float
    """

    _validation = {
        'coefficient': {'maximum': 5, 'minimum': 0},
    }

    _attribute_map = {
        'end_date': {'key': 'EndDate', 'type': 'iso-8601'},
        'coefficient': {'key': 'Coefficient', 'type': 'float'},
    }

    def __init__(self, *, end_date=None, coefficient: float=None, **kwargs) -> None:
        super(SmartAlarmsRequest, self).__init__(**kwargs)
        self.end_date = end_date
        self.coefficient = coefficient



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ThermalCameraResponse(Model):
    """ThermalCameraResponse.

    All required parameters must be populated in order to send to Azure.

    :param serial_number: Required.
    :type serial_number: long
    :param created:
    :type created: datetime
    :param updated:
    :type updated: datetime
    :param active:
    :type active: bool
    :param location: Required.
    :type location: ~smartdiagnostics_sdk.models.LocationChild
    :param settings: Required.
    :type settings: ~smartdiagnostics_sdk.models.ThermalCameraSettingsChild
    """

    _validation = {
        'serial_number': {'required': True},
        'location': {'required': True},
        'settings': {'required': True},
    }

    _attribute_map = {
        'serial_number': {'key': 'SerialNumber', 'type': 'long'},
        'created': {'key': 'Created', 'type': 'iso-8601'},
        'updated': {'key': 'Updated', 'type': 'iso-8601'},
        'active': {'key': 'Active', 'type': 'bool'},
        'location': {'key': 'Location', 'type': 'LocationChild'},
        'settings': {'key': 'Settings', 'type': 'ThermalCameraSettingsChild'},
    }

    def __init__(self, *, serial_number: int, location, settings, created=None, updated=None, active: bool=None, **kwargs) -> None:
        super(ThermalCameraResponse, self).__init__(**kwargs)
        self.serial_number = serial_number
        self.created = created
        self.updated = updated
        self.active = active
        self.location = location
        self.settings = settings



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventFieldResponse(Model):
    """ActivityEventFieldResponse.

    :param id:
    :type id: str
    :param code:
    :type code: str
    :param name:
    :type name: str
    :param description:
    :type description: str
    :param field_type: Possible values include: 'String', 'Bool', 'Int',
     'Float', 'Status'
    :type field_type: str or ~smartdiagnostics_sdk.models.enum
    """

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'code': {'key': 'Code', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'description': {'key': 'Description', 'type': 'str'},
        'field_type': {'key': 'FieldType', 'type': 'str'},
    }

    def __init__(self, *, id: str=None, code: str=None, name: str=None, description: str=None, field_type=None, **kwargs) -> None:
        super(ActivityEventFieldResponse, self).__init__(**kwargs)
        self.id = id
        self.code = code
        self.name = name
        self.description = description
        self.field_type = field_type



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventFieldEntryChild(Model):
    """ActivityEventFieldEntryChild.

    :param field_entry_id:
    :type field_entry_id: str
    :param field_value:
    :type field_value: str
    :param field_id:
    :type field_id: str
    :param field_code:
    :type field_code: str
    :param field_name:
    :type field_name: str
    :param field_type: Possible values include: 'String', 'Bool', 'Int',
     'Float', 'Status'
    :type field_type: str or ~smartdiagnostics_sdk.models.enum
    """

    _attribute_map = {
        'field_entry_id': {'key': 'FieldEntryId', 'type': 'str'},
        'field_value': {'key': 'FieldValue', 'type': 'str'},
        'field_id': {'key': 'FieldId', 'type': 'str'},
        'field_code': {'key': 'FieldCode', 'type': 'str'},
        'field_name': {'key': 'FieldName', 'type': 'str'},
        'field_type': {'key': 'FieldType', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ActivityEventFieldEntryChild, self).__init__(**kwargs)
        self.field_entry_id = kwargs.get('field_entry_id', None)
        self.field_value = kwargs.get('field_value', None)
        self.field_id = kwargs.get('field_id', None)
        self.field_code = kwargs.get('field_code', None)
        self.field_name = kwargs.get('field_name', None)
        self.field_type = kwargs.get('field_type', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AnalyticsLogResponse(Model):
    """AnalyticsLogResponse.

    All required parameters must be populated in order to send to Azure.

    :param message: Required.
    :type message: str
    :param date_property: Required.
    :type date_property: datetime
    """

    _validation = {
        'message': {'required': True},
        'date_property': {'required': True},
    }

    _attribute_map = {
        'message': {'key': 'Message', 'type': 'str'},
        'date_property': {'key': 'Date', 'type': 'iso-8601'},
    }

    def __init__(self, *, message: str, date_property, **kwargs) -> None:
        super(AnalyticsLogResponse, self).__init__(**kwargs)
        self.message = message
        self.date_property = date_property



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventCategoryResponse(Model):
    """ActivityEventCategoryResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: int
    :param code: Required.
    :type code: str
    :param name:
    :type name: str
    :param description:
    :type description: str
    :param activity_line_enabled:
    :type activity_line_enabled: bool
    :param activity_line_flag:
    :type activity_line_flag: str
    :param asset_card_enabled:
    :type asset_card_enabled: bool
    :param owner:
    :type owner: ~smartdiagnostics_sdk.models.ActivityEventCategoryOwnerChild
    :param internal:
    :type internal: bool
    :param subcategories:
    :type subcategories:
     list[~smartdiagnostics_sdk.models.ActivityEventSubcategoryChild]
    :param fields:
    :type fields: list[~smartdiagnostics_sdk.models.ActivityEventFieldChild]
    """

    _validation = {
        'id': {'required': True},
        'code': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'int'},
        'code': {'key': 'Code', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'description': {'key': 'Description', 'type': 'str'},
        'activity_line_enabled': {'key': 'ActivityLineEnabled', 'type': 'bool'},
        'activity_line_flag': {'key': 'ActivityLineFlag', 'type': 'str'},
        'asset_card_enabled': {'key': 'AssetCardEnabled', 'type': 'bool'},
        'owner': {'key': 'Owner', 'type': 'ActivityEventCategoryOwnerChild'},
        'internal': {'key': 'Internal', 'type': 'bool'},
        'subcategories': {'key': 'Subcategories', 'type': '[ActivityEventSubcategoryChild]'},
        'fields': {'key': 'Fields', 'type': '[ActivityEventFieldChild]'},
    }

    def __init__(self, *, id: int, code: str, name: str=None, description: str=None, activity_line_enabled: bool=None, activity_line_flag: str=None, asset_card_enabled: bool=None, owner=None, internal: bool=None, subcategories=None, fields=None, **kwargs) -> None:
        super(ActivityEventCategoryResponse, self).__init__(**kwargs)
        self.id = id
        self.code = code
        self.name = name
        self.description = description
        self.activity_line_enabled = activity_line_enabled
        self.activity_line_flag = activity_line_flag
        self.asset_card_enabled = asset_card_enabled
        self.owner = owner
        self.internal = internal
        self.subcategories = subcategories
        self.fields = fields



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ThermalCameraImageResponse(Model):
    """ThermalCameraImageResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: str
    :param timestamp: Required.
    :type timestamp: datetime
    :param image: Required.
    :type image: bytearray
    :param thermal_camera_serial_number: Required.
    :type thermal_camera_serial_number: long
    """

    _validation = {
        'id': {'required': True},
        'timestamp': {'required': True},
        'image': {'required': True},
        'thermal_camera_serial_number': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'timestamp': {'key': 'Timestamp', 'type': 'iso-8601'},
        'image': {'key': 'Image', 'type': 'bytearray'},
        'thermal_camera_serial_number': {'key': 'ThermalCameraSerialNumber', 'type': 'long'},
    }

    def __init__(self, **kwargs):
        super(ThermalCameraImageResponse, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.timestamp = kwargs.get('timestamp', None)
        self.image = kwargs.get('image', None)
        self.thermal_camera_serial_number = kwargs.get('thermal_camera_serial_number', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventSubcategoryChild(Model):
    """ActivityEventSubcategoryChild.

    :param subcategory_id:
    :type subcategory_id: str
    :param subcategory_code:
    :type subcategory_code: str
    :param subcategory_name:
    :type subcategory_name: str
    """

    _attribute_map = {
        'subcategory_id': {'key': 'SubcategoryId', 'type': 'str'},
        'subcategory_code': {'key': 'SubcategoryCode', 'type': 'str'},
        'subcategory_name': {'key': 'SubcategoryName', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ActivityEventSubcategoryChild, self).__init__(**kwargs)
        self.subcategory_id = kwargs.get('subcategory_id', None)
        self.subcategory_code = kwargs.get('subcategory_code', None)
        self.subcategory_name = kwargs.get('subcategory_name', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TokenExchangeResponse(Model):
    """TokenExchangeResponse.

    :param token:
    :type token: str
    """

    _attribute_map = {
        'token': {'key': 'Token', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(TokenExchangeResponse, self).__init__(**kwargs)
        self.token = kwargs.get('token', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IndicatorSensorRoleTypeCodeChild(Model):
    """IndicatorSensorRoleTypeCodeChild.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :param sensor_role_type_code: Possible values include: 'Invalid',
     'CurrentPhaseA', 'PeakCurrentPhaseA', 'CurrentPhaseB',
     'PeakCurrentPhaseB', 'CurrentPhaseC', 'PeakCurrentPhaseC',
     'DifferentialPressure', 'Flow', 'Humidity', 'NodeTemperature',
     'NodeVoltage', 'PeakVibration', 'Pressure', 'RmsVibration',
     'SignalStrength', 'StandardAirVelocity', 'SupplyVoltage', 'Temperature',
     'TotalCurrent', 'VibrationXAxis', 'VibrationYAxis', 'Voltage', 'Current',
     'AtoDChannel1', 'AtoDChannel2', 'AtoDChannel3', 'AtoDChannel4',
     'AtoDChannel5', 'AtoDChannel6', 'OilTemperature', 'OilHumidity', 'X', 'Y',
     'Z', 'Custom', 'WirelessEfficiency', 'PacketSuccessRate', 'NodeHumidity',
     'BurstSuccessRate'
    :type sensor_role_type_code: str or ~smartdiagnostics_sdk.models.enum
    :ivar sensor_role_type_code_formatted:
    :vartype sensor_role_type_code_formatted: str
    """

    _validation = {
        'sensor_role_type_code_formatted': {'readonly': True},
    }

    _attribute_map = {
        'sensor_role_type_code': {'key': 'SensorRoleTypeCode', 'type': 'str'},
        'sensor_role_type_code_formatted': {'key': 'SensorRoleTypeCodeFormatted', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(IndicatorSensorRoleTypeCodeChild, self).__init__(**kwargs)
        self.sensor_role_type_code = kwargs.get('sensor_role_type_code', None)
        self.sensor_role_type_code_formatted = None



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventCategoryOwnerChild(Model):
    """ActivityEventCategoryOwnerChild.

    :param owner_type: Possible values include: 'Global', 'Application',
     'Account'
    :type owner_type: str or ~smartdiagnostics_sdk.models.enum
    :param owner_id:
    :type owner_id: str
    """

    _attribute_map = {
        'owner_type': {'key': 'OwnerType', 'type': 'str'},
        'owner_id': {'key': 'OwnerId', 'type': 'str'},
    }

    def __init__(self, *, owner_type=None, owner_id: str=None, **kwargs) -> None:
        super(ActivityEventCategoryOwnerChild, self).__init__(**kwargs)
        self.owner_type = owner_type
        self.owner_id = owner_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BaseStationUpdateRequest(Model):
    """BaseStationUpdateRequest.

    :param nickname:
    :type nickname: str
    :param location_id:
    :type location_id: str
    :param release_ring_id:
    :type release_ring_id: str
    :param push_to_stage:
    :type push_to_stage: bool
    """

    _validation = {
        'nickname': {'max_length': 50},
    }

    _attribute_map = {
        'nickname': {'key': 'Nickname', 'type': 'str'},
        'location_id': {'key': 'LocationId', 'type': 'str'},
        'release_ring_id': {'key': 'ReleaseRingId', 'type': 'str'},
        'push_to_stage': {'key': 'PushToStage', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(BaseStationUpdateRequest, self).__init__(**kwargs)
        self.nickname = kwargs.get('nickname', None)
        self.location_id = kwargs.get('location_id', None)
        self.release_ring_id = kwargs.get('release_ring_id', None)
        self.push_to_stage = kwargs.get('push_to_stage', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IndicatorStatisticsResponse(Model):
    """IndicatorStatisticsResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: str
    :param name: Required.
    :type name: str
    :param system_sort_order:
    :type system_sort_order: int
    :param indicator_type: Required. Possible values include: 'Temperature',
     'Pressure', 'Flow', 'Humidity', 'Power', 'DifferentialPressure',
     'MultiSensorDifferentialPressure', 'Voltage', 'GeneralizedAtoD',
     'VibrationBandRms', 'VibrationBandMax', 'VibrationOverallPeak',
     'VibrationOverallRms', 'VibrationOverallSkewness',
     'VibrationOverallKurtosis', 'VibrationOverallCrestFactor',
     'DamageAccumulation', 'VibrationBandRmsAccel', 'VibrationBandMaxAccel',
     'VibrationOverallPeakAccel', 'VibrationOverallRmsAccel',
     'VibrationOverallSkewnessAccel', 'VibrationOverallKurtosisAccel',
     'VibrationOverallCrestFactorAccel', 'DamageAccumulationAccel', 'Group',
     'VibrationOverall', 'VibrationOverallAccel', 'GeneralTimeSeries', 'Math',
     'OnStatistics', 'OffStatistics', 'AlarmStatistics', 'WarningStatistics',
     'PositivePeakPressure', 'NegativePeakPressure', 'RmsPressure',
     'BandPressure', 'OnPercentStatistics', 'OffPercentStatistics',
     'AlarmPercentStatistics', 'WarningPercentStatistics', 'SignalStrength',
     'RunningSpeed', 'DamageAccumulationPressure', 'OilHumidity',
     'OilTemperature', 'DamageAccumulationAccelRaw', 'ThermalRegionOfInterest',
     'SmartMetric', 'Feature'
    :type indicator_type: str or ~smartdiagnostics_sdk.models.enum
    :param measure_of: Possible values include: 'Invalid', 'CurrentPhaseA',
     'PeakCurrentPhaseA', 'CurrentPhaseB', 'PeakCurrentPhaseB',
     'CurrentPhaseC', 'PeakCurrentPhaseC', 'DifferentialPressure', 'Flow',
     'Humidity', 'NodeTemperature', 'NodeVoltage', 'PeakVibration', 'Pressure',
     'RmsVibration', 'SignalStrength', 'StandardAirVelocity', 'SupplyVoltage',
     'Temperature', 'TotalCurrent', 'VibrationXAxis', 'VibrationYAxis',
     'Voltage', 'Current', 'AtoDChannel1', 'AtoDChannel2', 'AtoDChannel3',
     'AtoDChannel4', 'AtoDChannel5', 'AtoDChannel6', 'OilTemperature',
     'OilHumidity', 'X', 'Y', 'Z', 'Custom', 'WirelessEfficiency',
     'PacketSuccessRate', 'NodeHumidity', 'BurstSuccessRate'
    :type measure_of: str or ~smartdiagnostics_sdk.models.enum
    :param display_units:
    :type display_units: str
    :param last_measurement:
    :type last_measurement: datetime
    :param average_value:
    :type average_value: float
    :param max_value:
    :type max_value: float
    :param time_in_alarm:
    :type time_in_alarm: float
    :param time_in_warning:
    :type time_in_warning: float
    :param on_time:
    :type on_time: float
    :param hierarchy:
    :type hierarchy: list[~smartdiagnostics_sdk.models.HierarchyChild]
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
        'indicator_type': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'system_sort_order': {'key': 'SystemSortOrder', 'type': 'int'},
        'indicator_type': {'key': 'IndicatorType', 'type': 'str'},
        'measure_of': {'key': 'MeasureOf', 'type': 'str'},
        'display_units': {'key': 'DisplayUnits', 'type': 'str'},
        'last_measurement': {'key': 'LastMeasurement', 'type': 'iso-8601'},
        'average_value': {'key': 'AverageValue', 'type': 'float'},
        'max_value': {'key': 'MaxValue', 'type': 'float'},
        'time_in_alarm': {'key': 'TimeInAlarm', 'type': 'float'},
        'time_in_warning': {'key': 'TimeInWarning', 'type': 'float'},
        'on_time': {'key': 'OnTime', 'type': 'float'},
        'hierarchy': {'key': 'Hierarchy', 'type': '[HierarchyChild]'},
    }

    def __init__(self, *, id: str, name: str, indicator_type, system_sort_order: int=None, measure_of=None, display_units: str=None, last_measurement=None, average_value: float=None, max_value: float=None, time_in_alarm: float=None, time_in_warning: float=None, on_time: float=None, hierarchy=None, **kwargs) -> None:
        super(IndicatorStatisticsResponse, self).__init__(**kwargs)
        self.id = id
        self.name = name
        self.system_sort_order = system_sort_order
        self.indicator_type = indicator_type
        self.measure_of = measure_of
        self.display_units = display_units
        self.last_measurement = last_measurement
        self.average_value = average_value
        self.max_value = max_value
        self.time_in_alarm = time_in_alarm
        self.time_in_warning = time_in_warning
        self.on_time = on_time
        self.hierarchy = hierarchy



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AlertAcknowledgementRequest(Model):
    """AlertAcknowledgementRequest.

    All required parameters must be populated in order to send to Azure.

    :param group_ids: Required. IDs of groups for which all of the alerts
     under them should be acknowledged
    :type group_ids: list[str]
    """

    _validation = {
        'group_ids': {'required': True},
    }

    _attribute_map = {
        'group_ids': {'key': 'GroupIds', 'type': '[str]'},
    }

    def __init__(self, *, group_ids, **kwargs) -> None:
        super(AlertAcknowledgementRequest, self).__init__(**kwargs)
        self.group_ids = group_ids



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventHierarchyGroupRequest(Model):
    """ActivityEventHierarchyGroupRequest.

    All required parameters must be populated in order to send to Azure.

    :param start_date_time: Required.
    :type start_date_time: datetime
    :param end_date_time: Required.
    :type end_date_time: datetime
    :param indicator_ids:
    :type indicator_ids: list[str]
    :param group_ids:
    :type group_ids: list[str]
    :param category_ids:
    :type category_ids: list[int]
    :param activity_line_enabled:
    :type activity_line_enabled: bool
    :param location_id:
    :type location_id: str
    :param title:
    :type title: str
    """

    _validation = {
        'start_date_time': {'required': True},
        'end_date_time': {'required': True},
    }

    _attribute_map = {
        'start_date_time': {'key': 'StartDateTime', 'type': 'iso-8601'},
        'end_date_time': {'key': 'EndDateTime', 'type': 'iso-8601'},
        'indicator_ids': {'key': 'IndicatorIds', 'type': '[str]'},
        'group_ids': {'key': 'GroupIds', 'type': '[str]'},
        'category_ids': {'key': 'CategoryIds', 'type': '[int]'},
        'activity_line_enabled': {'key': 'ActivityLineEnabled', 'type': 'bool'},
        'location_id': {'key': 'LocationId', 'type': 'str'},
        'title': {'key': 'Title', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ActivityEventHierarchyGroupRequest, self).__init__(**kwargs)
        self.start_date_time = kwargs.get('start_date_time', None)
        self.end_date_time = kwargs.get('end_date_time', None)
        self.indicator_ids = kwargs.get('indicator_ids', None)
        self.group_ids = kwargs.get('group_ids', None)
        self.category_ids = kwargs.get('category_ids', None)
        self.activity_line_enabled = kwargs.get('activity_line_enabled', None)
        self.location_id = kwargs.get('location_id', None)
        self.title = kwargs.get('title', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventFieldEntryRequest(Model):
    """ActivityEventFieldEntryRequest.

    All required parameters must be populated in order to send to Azure.

    :param field_id:
    :type field_id: str
    :param field_code:
    :type field_code: str
    :param value: Required.
    :type value: str
    """

    _validation = {
        'value': {'required': True},
    }

    _attribute_map = {
        'field_id': {'key': 'FieldId', 'type': 'str'},
        'field_code': {'key': 'FieldCode', 'type': 'str'},
        'value': {'key': 'Value', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ActivityEventFieldEntryRequest, self).__init__(**kwargs)
        self.field_id = kwargs.get('field_id', None)
        self.field_code = kwargs.get('field_code', None)
        self.value = kwargs.get('value', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ThermalCameraRegionCreateRequest(Model):
    """ThermalCameraRegionCreateRequest.

    All required parameters must be populated in order to send to Azure.

    :param name: Required. The name of the region
    :type name: str
    :param xcoordinate: Required. The "X" coordinate that determines the
     position of the region.
     In other words, where the region is located.
    :type xcoordinate: int
    :param ycoordinate: Required. The "Y" coordinate that determines the
     position of the region.
     In other words, where the region is located.
    :type ycoordinate: int
    :param width: Required. The width of the region
    :type width: int
    :param height: Required. The height of the region
    :type height: int
    :param thermal_camera_serial_number: Required. The serial number for the
     Thermal Camera the region belongs to
    :type thermal_camera_serial_number: long
    :param instance: Required. The unique set of coordinates that designates a
     region.
     Each thermal camera can have up to 5 unique instances.
    :type instance: int
    """

    _validation = {
        'name': {'required': True, 'max_length': 50},
        'xcoordinate': {'required': True, 'maximum': 2147483647, 'minimum': 0},
        'ycoordinate': {'required': True, 'maximum': 2147483647, 'minimum': 0},
        'width': {'required': True, 'maximum': 2147483647, 'minimum': 0},
        'height': {'required': True, 'maximum': 2147483647, 'minimum': 0},
        'thermal_camera_serial_number': {'required': True},
        'instance': {'required': True, 'maximum': 5, 'minimum': 1},
    }

    _attribute_map = {
        'name': {'key': 'Name', 'type': 'str'},
        'xcoordinate': {'key': 'XCoordinate', 'type': 'int'},
        'ycoordinate': {'key': 'YCoordinate', 'type': 'int'},
        'width': {'key': 'Width', 'type': 'int'},
        'height': {'key': 'Height', 'type': 'int'},
        'thermal_camera_serial_number': {'key': 'ThermalCameraSerialNumber', 'type': 'long'},
        'instance': {'key': 'Instance', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(ThermalCameraRegionCreateRequest, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.xcoordinate = kwargs.get('xcoordinate', None)
        self.ycoordinate = kwargs.get('ycoordinate', None)
        self.width = kwargs.get('width', None)
        self.height = kwargs.get('height', None)
        self.thermal_camera_serial_number = kwargs.get('thermal_camera_serial_number', None)
        self.instance = kwargs.get('instance', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventBindChild(Model):
    """ActivityEventBindChild.

    :param bind_id:
    :type bind_id: str
    :param bind_type: Possible values include: 'Group', 'Metric',
     'EvidenceMetric', 'Model', 'GroupModel'
    :type bind_type: str or ~smartdiagnostics_sdk.models.enum
    """

    _attribute_map = {
        'bind_id': {'key': 'BindId', 'type': 'str'},
        'bind_type': {'key': 'BindType', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ActivityEventBindChild, self).__init__(**kwargs)
        self.bind_id = kwargs.get('bind_id', None)
        self.bind_type = kwargs.get('bind_type', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ThermalCameraSettingsChild(Model):
    """ThermalCameraSettingsChild.

    :param atmosphere_temperature: The ambient temperature on the camera in
     Kelvin.
    :type atmosphere_temperature: float
    :param emissivity: The Emissivity value used in calculating temperature.
    :type emissivity: float
    :param distance:
    :type distance: float
    :param reflected_temperature: The reflected temperature of the object in
     Kelvin.
    :type reflected_temperature: float
    :param relative_humidity: The relative humidity of the camera.
    :type relative_humidity: float
    :param window_transmission_rate: The amount of thermal radiation allowed
     through an external window.
    :type window_transmission_rate: float
    :param window_temperature: The temperature of any external thermal windows
     in Kelvin.
    :type window_temperature: float
    :param update_interval: How often a value is transmitted to SD
    :type update_interval: int
    """

    _validation = {
        'emissivity': {'maximum': 1, 'minimum': 0.001},
        'relative_humidity': {'maximum': 1, 'minimum': 0},
        'window_transmission_rate': {'maximum': 1, 'minimum': 0.001},
    }

    _attribute_map = {
        'atmosphere_temperature': {'key': 'AtmosphereTemperature', 'type': 'float'},
        'emissivity': {'key': 'Emissivity', 'type': 'float'},
        'distance': {'key': 'Distance', 'type': 'float'},
        'reflected_temperature': {'key': 'ReflectedTemperature', 'type': 'float'},
        'relative_humidity': {'key': 'RelativeHumidity', 'type': 'float'},
        'window_transmission_rate': {'key': 'WindowTransmissionRate', 'type': 'float'},
        'window_temperature': {'key': 'WindowTemperature', 'type': 'float'},
        'update_interval': {'key': 'UpdateInterval', 'type': 'int'},
    }

    def __init__(self, *, atmosphere_temperature: float=None, emissivity: float=None, distance: float=None, reflected_temperature: float=None, relative_humidity: float=None, window_transmission_rate: float=None, window_temperature: float=None, update_interval: int=None, **kwargs) -> None:
        super(ThermalCameraSettingsChild, self).__init__(**kwargs)
        self.atmosphere_temperature = atmosphere_temperature
        self.emissivity = emissivity
        self.distance = distance
        self.reflected_temperature = reflected_temperature
        self.relative_humidity = relative_humidity
        self.window_transmission_rate = window_transmission_rate
        self.window_temperature = window_temperature
        self.update_interval = update_interval



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventFieldValueRequest(Model):
    """ActivityEventFieldValueRequest.

    All required parameters must be populated in order to send to Azure.

    :param value: Required.
    :type value: str
    :param label:
    :type label: str
    :param order:
    :type order: int
    """

    _validation = {
        'value': {'required': True},
    }

    _attribute_map = {
        'value': {'key': 'Value', 'type': 'str'},
        'label': {'key': 'Label', 'type': 'str'},
        'order': {'key': 'Order', 'type': 'int'},
    }

    def __init__(self, *, value: str, label: str=None, order: int=None, **kwargs) -> None:
        super(ActivityEventFieldValueRequest, self).__init__(**kwargs)
        self.value = value
        self.label = label
        self.order = order



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ThermalCameraRegionResponse(Model):
    """ThermalCameraRegionResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required. The ID for the region
    :type id: str
    :param name: Required. The name of the region
    :type name: str
    :param instance: Required. The unique set of coordinates that designates a
     region.
    :type instance: int
    :param xcoordinate: Required. The "X" coordinate that determines the
     position of the region.
     In other words, where the region is located.
    :type xcoordinate: int
    :param ycoordinate: Required. The "Y" coordinate that determines the
     position of the region.
     In other words, where the region is located.
    :type ycoordinate: int
    :param width: Required. The width of the region
    :type width: int
    :param height: Required. The height of the region
    :type height: int
    :param created: Required. The Date the thermal region was originally
     created
    :type created: datetime
    :param updated: Required. Represents the last time the region had
     properties that were updated
    :type updated: datetime
    :param active: Required. Whether or not the thermal region is currently
     active
    :type active: bool
    :param thermal_camera_serial_number: Required. The serial number for the
     Thermal Camera the region belongs to
    :type thermal_camera_serial_number: long
    :param location: Required.
    :type location:
     ~smartdiagnostics_sdk.models.ThermalCameraRegionLocationChild
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
        'instance': {'required': True},
        'xcoordinate': {'required': True},
        'ycoordinate': {'required': True},
        'width': {'required': True},
        'height': {'required': True},
        'created': {'required': True},
        'updated': {'required': True},
        'active': {'required': True},
        'thermal_camera_serial_number': {'required': True},
        'location': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'name': {'key': 'Name', 'type': 'str'},
        'instance': {'key': 'Instance', 'type': 'int'},
        'xcoordinate': {'key': 'XCoordinate', 'type': 'int'},
        'ycoordinate': {'key': 'YCoordinate', 'type': 'int'},
        'width': {'key': 'Width', 'type': 'int'},
        'height': {'key': 'Height', 'type': 'int'},
        'created': {'key': 'Created', 'type': 'iso-8601'},
        'updated': {'key': 'Updated', 'type': 'iso-8601'},
        'active': {'key': 'Active', 'type': 'bool'},
        'thermal_camera_serial_number': {'key': 'ThermalCameraSerialNumber', 'type': 'long'},
        'location': {'key': 'Location', 'type': 'ThermalCameraRegionLocationChild'},
    }

    def __init__(self, *, id: str, name: str, instance: int, xcoordinate: int, ycoordinate: int, width: int, height: int, created, updated, active: bool, thermal_camera_serial_number: int, location, **kwargs) -> None:
        super(ThermalCameraRegionResponse, self).__init__(**kwargs)
        self.id = id
        self.name = name
        self.instance = instance
        self.xcoordinate = xcoordinate
        self.ycoordinate = ycoordinate
        self.width = width
        self.height = height
        self.created = created
        self.updated = updated
        self.active = active
        self.thermal_camera_serial_number = thermal_camera_serial_number
        self.location = location



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventCategoryChild(Model):
    """ActivityEventCategoryChild.

    :param category_id:
    :type category_id: int
    :param category_code:
    :type category_code: str
    :param category_name:
    :type category_name: str
    :param category_owner_type: Possible values include: 'Global',
     'Application', 'Account'
    :type category_owner_type: str or ~smartdiagnostics_sdk.models.enum
    """

    _attribute_map = {
        'category_id': {'key': 'CategoryId', 'type': 'int'},
        'category_code': {'key': 'CategoryCode', 'type': 'str'},
        'category_name': {'key': 'CategoryName', 'type': 'str'},
        'category_owner_type': {'key': 'CategoryOwnerType', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ActivityEventCategoryChild, self).__init__(**kwargs)
        self.category_id = kwargs.get('category_id', None)
        self.category_code = kwargs.get('category_code', None)
        self.category_name = kwargs.get('category_name', None)
        self.category_owner_type = kwargs.get('category_owner_type', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventHierarchyGroupResponse(Model):
    """ActivityEventHierarchyGroupResponse.

    All required parameters must be populated in order to send to Azure.

    :param id: Required.
    :type id: str
    :param title: Required.
    :type title: str
    :param description:
    :type description: str
    :param start_date_time: Required.
    :type start_date_time: datetime
    :param end_date_time:
    :type end_date_time: datetime
    :param activity_line_enabled:
    :type activity_line_enabled: bool
    :param created: Required.
    :type created: datetime
    :param created_by: Required.
    :type created_by: str
    :param location: Required.
    :type location: ~smartdiagnostics_sdk.models.LocationChild
    :param category: Required.
    :type category: ~smartdiagnostics_sdk.models.ActivityEventCategoryChild
    :param hierarchy: Required.
    :type hierarchy: list[~smartdiagnostics_sdk.models.HierarchyChild]
    :param indicators:
    :type indicators:
     list[~smartdiagnostics_sdk.models.ActivityEventIndicatorChild]
    """

    _validation = {
        'id': {'required': True},
        'title': {'required': True},
        'start_date_time': {'required': True},
        'created': {'required': True},
        'created_by': {'required': True},
        'location': {'required': True},
        'category': {'required': True},
        'hierarchy': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'Id', 'type': 'str'},
        'title': {'key': 'Title', 'type': 'str'},
        'description': {'key': 'Description', 'type': 'str'},
        'start_date_time': {'key': 'StartDateTime', 'type': 'iso-8601'},
        'end_date_time': {'key': 'EndDateTime', 'type': 'iso-8601'},
        'activity_line_enabled': {'key': 'ActivityLineEnabled', 'type': 'bool'},
        'created': {'key': 'Created', 'type': 'iso-8601'},
        'created_by': {'key': 'CreatedBy', 'type': 'str'},
        'location': {'key': 'Location', 'type': 'LocationChild'},
        'category': {'key': 'Category', 'type': 'ActivityEventCategoryChild'},
        'hierarchy': {'key': 'Hierarchy', 'type': '[HierarchyChild]'},
        'indicators': {'key': 'Indicators', 'type': '[ActivityEventIndicatorChild]'},
    }

    def __init__(self, **kwargs):
        super(ActivityEventHierarchyGroupResponse, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.title = kwargs.get('title', None)
        self.description = kwargs.get('description', None)
        self.start_date_time = kwargs.get('start_date_time', None)
        self.end_date_time = kwargs.get('end_date_time', None)
        self.activity_line_enabled = kwargs.get('activity_line_enabled', None)
        self.created = kwargs.get('created', None)
        self.created_by = kwargs.get('created_by', None)
        self.location = kwargs.get('location', None)
        self.category = kwargs.get('category', None)
        self.hierarchy = kwargs.get('hierarchy', None)
        self.indicators = kwargs.get('indicators', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class IndicatorOptionsResponse(Model):
    """IndicatorOptionsResponse.

    :param sensor_role_type_codes:
    :type sensor_role_type_codes:
     list[~smartdiagnostics_sdk.models.IndicatorSensorRoleTypeCodeChild]
    """

    _attribute_map = {
        'sensor_role_type_codes': {'key': 'SensorRoleTypeCodes', 'type': '[IndicatorSensorRoleTypeCodeChild]'},
    }

    def __init__(self, **kwargs):
        super(IndicatorOptionsResponse, self).__init__(**kwargs)
        self.sensor_role_type_codes = kwargs.get('sensor_role_type_codes', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MarkerChild(Model):
    """MarkerChild.

    All required parameters must be populated in order to send to Azure.

    :param marker_name:
    :type marker_name: str
    :param marker_show_harmonics: Required.
    :type marker_show_harmonics: bool
    :param marker_show_side_bands: Required.
    :type marker_show_side_bands: bool
    :param marker_show_peaks: Required.
    :type marker_show_peaks: bool
    """

    _validation = {
        'marker_name': {'max_length': 5},
        'marker_show_harmonics': {'required': True},
        'marker_show_side_bands': {'required': True},
        'marker_show_peaks': {'required': True},
    }

    _attribute_map = {
        'marker_name': {'key': 'MarkerName', 'type': 'str'},
        'marker_show_harmonics': {'key': 'MarkerShowHarmonics', 'type': 'bool'},
        'marker_show_side_bands': {'key': 'MarkerShowSideBands', 'type': 'bool'},
        'marker_show_peaks': {'key': 'MarkerShowPeaks', 'type': 'bool'},
    }

    def __init__(self, *, marker_show_harmonics: bool, marker_show_side_bands: bool, marker_show_peaks: bool, marker_name: str=None, **kwargs) -> None:
        super(MarkerChild, self).__init__(**kwargs)
        self.marker_name = marker_name
        self.marker_show_harmonics = marker_show_harmonics
        self.marker_show_side_bands = marker_show_side_bands
        self.marker_show_peaks = marker_show_peaks



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ActivityEventUpdateRequest(Model):
    """ActivityEventUpdateRequest.

    :param clear_existing_binds:
    :type clear_existing_binds: bool
    :param title:
    :type title: str
    :param description:
    :type description: str
    :param start_date_time:
    :type start_date_time: datetime
    :param end_date_time:
    :type end_date_time: datetime
    :param subcategories:
    :type subcategories:
     list[~smartdiagnostics_sdk.models.ActivityEventSubcategoryEntryRequest]
    :param binds:
    :type binds: list[~smartdiagnostics_sdk.models.ActivityEventBindRequest]
    :param fields:
    :type fields:
     list[~smartdiagnostics_sdk.models.ActivityEventFieldEntryRequest]
    """

    _validation = {
        'title': {'max_length': 50, 'min_length': 0},
        'description': {'max_length': 1000, 'min_length': 0},
    }

    _attribute_map = {
        'clear_existing_binds': {'key': 'ClearExistingBinds', 'type': 'bool'},
        'title': {'key': 'Title', 'type': 'str'},
        'description': {'key': 'Description', 'type': 'str'},
        'start_date_time': {'key': 'StartDateTime', 'type': 'iso-8601'},
        'end_date_time': {'key': 'EndDateTime', 'type': 'iso-8601'},
        'subcategories': {'key': 'Subcategories', 'type': '[ActivityEventSubcategoryEntryRequest]'},
        'binds': {'key': 'Binds', 'type': '[ActivityEventBindRequest]'},
        'fields': {'key': 'Fields', 'type': '[ActivityEventFieldEntryRequest]'},
    }

    def __init__(self, *, clear_existing_binds: bool=None, title: str=None, description: str=None, start_date_time=None, end_date_time=None, subcategories=None, binds=None, fields=None, **kwargs) -> None:
        super(ActivityEventUpdateRequest, self).__init__(**kwargs)
        self.clear_existing_binds = clear_existing_binds
        self.title = title
        self.description = description
        self.start_date_time = start_date_time
        self.end_date_time = end_date_time
        self.subcategories = subcategories
        self.binds = binds
        self.fields = fields



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AcknowledgedAlertsResponse(Model):
    """AcknowledgedAlertsResponse.

    All required parameters must be populated in order to send to Azure.

    :param alerts_acknowledged: Required. The number of alerts that were
     acknowledged
    :type alerts_acknowledged: int
    """

    _validation = {
        'alerts_acknowledged': {'required': True},
    }

    _attribute_map = {
        'alerts_acknowledged': {'key': 'AlertsAcknowledged', 'type': 'int'},
    }

    def __init__(self, *, alerts_acknowledged: int, **kwargs) -> None:
        super(AcknowledgedAlertsResponse, self).__init__(**kwargs)
        self.alerts_acknowledged = alerts_acknowledged



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AnalyticsModelRelatedModelChild(Model):
    """AnalyticsModelRelatedModelChild.

    :param related_model_id:
    :type related_model_id: str
    :param related_model_name:
    :type related_model_name: str
    :param related_model_type: Possible values include: 'SMARTIndicator',
     'Classifier'
    :type related_model_type: str or ~smartdiagnostics_sdk.models.enum
    """

    _attribute_map = {
        'related_model_id': {'key': 'RelatedModelId', 'type': 'str'},
        'related_model_name': {'key': 'RelatedModelName', 'type': 'str'},
        'related_model_type': {'key': 'RelatedModelType', 'type': 'str'},
    }

    def __init__(self, *, related_model_id: str=None, related_model_name: str=None, related_model_type=None, **kwargs) -> None:
        super(AnalyticsModelRelatedModelChild, self).__init__(**kwargs)
        self.related_model_id = related_model_id
        self.related_model_name = related_model_name
        self.related_model_type = related_model_type
